<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 */

if ( ! function_exists( 'blog_diary_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Blog Diary Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function blog_diary_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'blog_diary_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'blog_diary_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Blog Diary Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function blog_diary_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'blog_diary_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'blog_diary_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Blog Diary Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function blog_diary_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'blog_diary_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if secondary nav section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_secondary_nav_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[top_bar_nav_section_enable]' )->value() );
}

/**
 * Check if slider section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is post.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[slider_content_type]' )->value();
	return blog_diary_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[slider_content_type]' )->value();
	return blog_diary_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is custom.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[slider_content_type]' )->value();
	return blog_diary_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if slider section content type is product.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_slider_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[slider_content_type]' )->value();
	return blog_diary_pro_is_slider_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if slider section content type is product-category.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_slider_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[slider_content_type]' )->value();
	return blog_diary_pro_is_slider_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if featured slider section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_featured_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[featured_slider_section_enable]' )->value() );
}

/**
 * Check if latest_posts section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_latest_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[latest_posts_section_enable]' )->value() );
}

/**
 * Check if latest_posts section content type is post.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_latest_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[latest_posts_content_type]' )->value();
	return blog_diary_pro_is_latest_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if latest_posts section content type is page.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_latest_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[latest_posts_content_type]' )->value();
	return blog_diary_pro_is_latest_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if latest_posts section content type is custom.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_latest_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[latest_posts_content_type]' )->value();
	return blog_diary_pro_is_latest_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if must_read_posts section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_must_read_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[must_read_posts_section_enable]' )->value() );
}

/**
 * Check if must_read_posts section content type is post.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_must_read_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[must_read_posts_content_type]' )->value();
	return blog_diary_pro_is_must_read_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if must_read_posts section content type is page.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_must_read_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[must_read_posts_content_type]' )->value();
	return blog_diary_pro_is_must_read_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if must_read_posts section content type is custom.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_must_read_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[must_read_posts_content_type]' )->value();
	return blog_diary_pro_is_must_read_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[blog_content_type]' )->value();
	return blog_diary_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[blog_content_type]' )->value();
	return blog_diary_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[blog_content_type]' )->value();
	return blog_diary_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[blog_content_type]' )->value();
	return blog_diary_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is page.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[service_content_type]' )->value();
	return blog_diary_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is post.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[service_content_type]' )->value();
	return blog_diary_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[service_content_type]' )->value();
	return blog_diary_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if service section seperator.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_service_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[service_content_type]' )->value();
	return blog_diary_pro_is_service_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if video section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_video_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[video_section_enable]' )->value() );
}

/**
 * Check if video section content type is post.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_video_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[video_content_type]' )->value();
	return blog_diary_pro_is_video_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if video section content type is page.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_video_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[video_content_type]' )->value();
	return blog_diary_pro_is_video_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if video section content type is custom.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_video_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[video_content_type]' )->value();
	return blog_diary_pro_is_video_section_enable( $control ) && ( 'custom' == $content_type );
}

/*About Section*/

/**
 * Check if about section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_about_section_enable( $control ) {
    return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is post.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_about_section_content_post_enable( $control ) {
    $content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[about_content_type]' )->value();
    return blog_diary_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_about_section_content_page_enable( $control ) {
    $content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[about_content_type]' )->value();
    return blog_diary_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_about_section_content_custom_enable( $control ) {
    $content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[about_content_type]' )->value();
    return blog_diary_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}
/*Emd About*/

/*Counter*/

/**
 * Check if counter section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[counter_section_enable]' )->value() );
}

/*End Counter*/

/*Team*/

/**
 * Check if team section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is post.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[team_content_type]' )->value();
	return blog_diary_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section content type is custom.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_team_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[team_content_type]' )->value();
	return blog_diary_pro_is_team_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if team section seperator.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_team_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[team_content_type]' )->value();
	return blog_diary_pro_is_team_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if team section content type is page.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[team_content_type]' )->value();
	return blog_diary_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is category.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[team_content_type]' )->value();
	return blog_diary_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/*EndTeam*/

/**
 * Check if subscription section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[subscription_section_enable]' )->value() );
}

/*Popular Destination*/

/**
 * Check if popular destination section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_popular_destination_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[popular_destination_section_enable]' )->value() );
}

/**
 * Check if popular destination section content type is page.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_popular_destination_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[popular_destination_content_type]' )->value();
	return blog_diary_pro_is_popular_destination_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular destination section content type is post.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_popular_destination_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[popular_destination_content_type]' )->value();
	return blog_diary_pro_is_popular_destination_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular destination section content type is trip.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_popular_destination_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[popular_destination_content_type]' )->value();
	return blog_diary_pro_is_popular_destination_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if popular destination section content type is category.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_popular_destination_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[popular_destination_content_type]' )->value();
	return blog_diary_pro_is_popular_destination_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular destination section content type is trip types.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_popular_destination_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[popular_destination_content_type]' )->value();
	return blog_diary_pro_is_popular_destination_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if popular destination section content type is destination.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_popular_destination_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[popular_destination_content_type]' )->value();
	return blog_diary_pro_is_popular_destination_section_enable( $control ) && ( 'destination' == $content_type );
}

/**
 * Check if popular destination section content type is activity.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_popular_destination_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[popular_destination_content_type]' )->value();
	return blog_diary_pro_is_popular_destination_section_enable( $control ) && ( 'activity' == $content_type );
}

/*End Popular Destination*/

/*Popular Tour*/

/**
 * Check if popular tours section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_popular_tours_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[popular_tours_section_enable]' )->value() );
}

/**
 * Check if popular tours section content type is page.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_popular_tours_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[popular_tours_content_type]' )->value();
	return blog_diary_pro_is_popular_tours_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular tours section content type is post.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_popular_tours_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[popular_tours_content_type]' )->value();
	return blog_diary_pro_is_popular_tours_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular tours section content type is trip.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_popular_tours_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[popular_tours_content_type]' )->value();
	return blog_diary_pro_is_popular_tours_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if popular tours section content type is category.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_popular_tours_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[popular_tours_content_type]' )->value();
	return blog_diary_pro_is_popular_tours_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular tours section content type is trip types.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_popular_tours_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[popular_tours_content_type]' )->value();
	return blog_diary_pro_is_popular_tours_section_enable( $control ) && ( 'trip-types' == $content_type );
}

/**
 * Check if popular tours section content type is tours.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_popular_tours_section_content_tours_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[popular_tours_content_type]' )->value();
	return blog_diary_pro_is_popular_tours_section_enable( $control ) && ( 'tours' == $content_type );
}

/**
 * Check if popular tours section content type is activity.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_popular_tours_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[popular_tours_content_type]' )->value();
	return blog_diary_pro_is_popular_tours_section_enable( $control ) && ( 'activity' == $content_type );
}

/*End Popular Tour*/

/*testimonial*/
	
/**
 * Check if testimonial section content type is post.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[testimonial_content_type]' )->value();
	return blog_diary_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[testimonial_content_type]' )->value();
	return blog_diary_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[testimonial_content_type]' )->value();
	return blog_diary_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is custom.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[testimonial_content_type]' )->value();
	return blog_diary_pro_is_testimonial_section_enable( $control ) && ( 'custom' == $content_type );
}


/**
 * Check if testimonial section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[testimonial_section_enable]' )->value() );
}

/*end testimonial*/

/*event*/

/**
 * Check if event section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_event_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[event_section_enable]' )->value() );
}

/**
 * Check if event section content type is post.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_event_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[event_content_type]' )->value();
	return blog_diary_pro_is_event_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if event section content type is page.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_event_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[event_content_type]' )->value();
	return blog_diary_pro_is_event_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if event section content type is category.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_event_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[event_content_type]' )->value();
	return blog_diary_pro_is_event_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if event section content type is event.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_event_section_content_event_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[event_content_type]' )->value();
	return blog_diary_pro_is_event_section_enable( $control ) && ( 'event' == $content_type );
}

/**
 * Check if event section content type is event category.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_event_section_content_event_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[event_content_type]' )->value();
	return blog_diary_pro_is_event_section_enable( $control ) && ( 'event-category' == $content_type );
}

/*end event*/

/*cta*/
/**
 * Check if video section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if cta section content type is post.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[cta_content_type]' )->value();
	return blog_diary_pro_is_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[cta_content_type]' )->value();
	return blog_diary_pro_is_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if cta section content type is custom.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_cta_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[cta_content_type]' )->value();
	return blog_diary_pro_is_cta_section_enable( $control ) && ( 'custom' == $content_type );
}
/*end cta*/

/*release*/

/**
 * Check if release section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_release_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[release_section_enable]' )->value() );
}

/**
 * Check if release section content type is post.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_release_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[release_content_type]' )->value();
	return blog_diary_pro_is_release_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if release section content type is page.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_release_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[release_content_type]' )->value();
	return blog_diary_pro_is_release_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if release section content type is category.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_release_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[release_content_type]' )->value();
	return blog_diary_pro_is_release_section_enable( $control ) && ( 'category' == $content_type );
}

/*end release*/

/*recent product*/

/**
 * Check if recent_product section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_recent_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[recent_product_section_enable]' )->value() );
}

function blog_diary_pro_is_recent_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[recent_product_content_type]' )->value();
	return blog_diary_pro_is_recent_product_section_enable( $control ) && ( 'product' == $content_type );
}

function blog_diary_pro_is_recent_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'blog_diary_pro_theme_options[recent_product_content_type]' )->value();
	return blog_diary_pro_is_recent_product_section_enable( $control ) && ( 'product-cat' == $content_type );
}

/*end recent product*/

/*masonry*/

/**
 * Check if product section is enabled.
 *
 * @since Blog Diary Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function blog_diary_pro_is_masonry_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[masonry_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/* end masonry*/


//featured section
function blog_diary_pro_is_featured_section_enable( $control ) {
	return ( $control->manager->get_setting( 'blog_diary_pro_theme_options[featured_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}